@@ -70,15 +70,15 @@ class Speaker(models.Model):
         cursor.execute("""Select avg(AvgF1), avg(AvgF2) FROM (SELECT StressVowel as Vowel,
 avg(StrVowelF1) as AvgF1,
 avg(StrVowelF2) as AvgF2
- FROM LingToolsWebsite.buckeye_wordtoken
-Inner join buckeye_wordtype
-ON buckeye_wordtype.id =buckeye_wordtoken.WordType_id
-Inner join buckeye_dialog
-ON buckeye_dialog.id = buckeye_wordtoken.Dialog_id
-Inner join buckeye_speaker
-ON buckeye_speaker.id = buckeye_dialog.Speaker_id
+ FROM buckeyebrowser_wordtoken
+Inner join buckeyebrowser_wordtype
+ON buckeyebrowser_wordtype.id =buckeyebrowser_wordtoken.WordType_id
+Inner join buckeyebrowser_dialog
+ON buckeyebrowser_dialog.id = buckeyebrowser_wordtoken.Dialog_id
+Inner join buckeyebrowser_speaker
+ON buckeyebrowser_speaker.id = buckeyebrowser_dialog.Speaker_id
 WHERE CVSkel = 'CVC'
-AND buckeye_dialog.Speaker_id = %s
+AND buckeyebrowser_dialog.Speaker_id = %s
 Group by StressVowel) AS averages""",[self.pk])
         center = cursor.fetchone()
         return (center[0],center[1])
